/// <reference types="node" />
import { Transferable as DefaultTransferable, ExternalCopy, Reference } from '@forge/isolated-vm';
export declare enum ValidApiMethods {
    'api.fetch' = 0,
    'setTimeout' = 1,
    'clearTimeout' = 2,
    'setInterval' = 3,
    'clearInterval' = 4,
    'crypto.randomFillSync' = 5,
    'api.asUser.requestAtlassian' = 6,
    'api.asUser.requestConfluence' = 7,
    'api.asUser.requestJira' = 8,
    'api.asUser.withProvider.fetch' = 9,
    'api.asUser.withProvider.requestCredentials' = 10,
    'api.asUser.withProvider.hasCredentials' = 11,
    'api.asApp.requestAtlassian' = 12,
    'api.asApp.requestConfluence' = 13,
    'api.asApp.requestJira' = 14,
    'api.requestJira' = 15,
    'api.requestConfluence' = 16,
    'api.getAuthTokenReferences' = 17,
    'api.getAppAri' = 18,
    'api.webTrigger.getUrl' = 19,
    'logConsole' = 20,
    'getUserVars' = 21
}
export declare type ValidApiMethodsType = keyof typeof ValidApiMethods;
export declare type ConsoleMethod = 'debug' | 'error' | 'info' | 'log' | 'warn';
export interface WrapOpts {
    release?: any;
    transfer?: any;
}
export declare type toExternalCopy = (arg: Transferable) => ExternalCopy<Transferable>;
export declare type toReference = (arg: Function, opts?: WrapOpts) => Reference<Function>;
export interface Serializer {
    serialize: (copy: toExternalCopy, wrap: toReference) => Transferable;
}
export declare type Transferable = DefaultTransferable | Record<string, any>;
export declare type BridgeArg = Transferable | Serializer | Function;
export interface Bridge {
    call(fn: ValidApiMethodsType, ...args: BridgeArg[]): any;
    callSync(fn: ValidApiMethodsType, ...args: BridgeArg[]): any;
    callIgnored(fn: ValidApiMethodsType, ...args: BridgeArg[]): any;
}
export interface ProcessStaticConfig {
    versions: NodeJS.ProcessVersions;
    version: string;
    platform: 'forge';
    env: Record<string, any>;
}
export interface RuntimeStaticConfig {
    process: ProcessStaticConfig;
}
export interface GlobalDefinitionInterface {
    define(bridge: Bridge, global: any, options?: Record<string, any>): void;
}
export interface DeferedMethodInvocation {
    method: string;
    args: unknown[];
}
//# sourceMappingURL=runtime-core-types.d.ts.map